suppressMessages(library(DESeq2))
library(matrixStats)

### taskid
#slar_taskid <- as.numeric(Sys.getenv("SLURM_ARRAY_TASK_ID")) #1:750
for(slar_taskid in 1:750){

  load("../Data/seeds_dearseq_GBresponse.RData")
  cat("slar_taskid: ", slar_taskid, "\n")
  cat("seed used: ", seeds[slar_taskid], "\n\n")
  set.seed(seeds[slar_taskid])
  mc <- (slar_taskid -1 )%%750 %/% length(3:17) + 1
  subsample_index <- readRDS("../Data/subsample_index.rds")
  s <- (slar_taskid -1) %% (length(3:17)) + 3

  count_raw <- read.table("../Data/HeartAtrialAppendage.HeartLeftVentricle.gene_readCount.tsv",
                          sep = '\t', header = TRUE, row.names = 1)
  rownames(count_raw) <- as.character(1:nrow(count_raw))
  conditions <- read.table("../Data/HeartAtrialAppendage.HeartLeftVentricle.conditions.tsv", sep = '\t')
  condition_fact <- as.factor(as.matrix(conditions)[1, ])

  dis0 <- readRDS("../Data/HeartAtrialAppendage.HeartLeftVentricle_dis.rds")
  trueDE <- as.character(intersect(intersect(intersect(intersect(dis0[[1]], dis0[[2]]), dis0[[3]]), dis0[[4]]), dis0[[5]]))


  for(norm in c("nonorm", "permprenorm", "permpostnorm")){

    readCount <- count_raw
    condition <- condition_fact
    names(condition) <- NULL

    if(s ==17){
      sampsize <- "full"
    }else{
      sampsize <- length(subsample_index[[s]][[mc]][[1]])
    }

    message("computing sample size of ", sampsize, " with ", norm, " for simulation #", mc, "...")

    if(norm =="permprenorm"){
      # Permutation under H0
      trueDE_samplehalf <- sample(trueDE, length(trueDE)/2)
      readCount[!(rownames(readCount) %in% trueDE_samplehalf), ] <-
        t(apply(readCount[!(rownames(readCount) %in% trueDE_samplehalf), ], 1, sample))
    }

    if(norm !="nonorm"){
      # Normalization
      dds <- DESeqDataSetFromMatrix(readCount, DataFrame(condition), ~ condition)
      dds <- estimateSizeFactors(dds)
    }else{
      dds <- DESeqDataSetFromMatrix(readCount, DataFrame(condition), ~ condition)
      dds$sizeFactor <- rep(1, ncol(readCount))
      names(dds$sizeFactor) <- colnames(readCount)
    }

    if(norm == "permpostnorm" | norm == "nonorm"){
      # Permutation under H0
      trueDE_samplehalf <- sample(trueDE, length(trueDE)/2)
      counts(dds)[!(rownames(counts(dds)) %in% trueDE_samplehalf), ] <-
        t(apply(counts(dds)[!(rownames(counts(dds)) %in% trueDE_samplehalf), ], 1, sample))
    }

    if(s != 17){
      subsamples <- unlist(subsample_index[[s]][[mc]])

      dds <- dds[, subsamples]
      condition <- condition[subsamples]
    }


    # Remove zero variance genes
    dds <- dds[matrixStats::rowVars(counts(dds))>0, ]

    # Estimation
    dds <- estimateDispersions(dds)
    dds <- nbinomWaldTest(dds)
    res <- results(dds, alpha = 0.05)
    DESeq2_res_pvals <- cbind.data.frame("rawPvals" = res$pvalue[!is.na(res$pvalue)],
                                         "adjPvals" = p.adjust(res$pvalue[!is.na(res$pvalue)], method = "fdr"),
                                         "GeneIndex" = rownames(counts(dds))[!is.na(res$pvalue)]
    )
    DESeq2_res_pvals$TrueDE <- DESeq2_res_pvals$GeneIndex %in% trueDE_samplehalf
    write.table(DESeq2_res_pvals,
                file=paste0("DESeq2_3norms/DESeq2_res_pvals_", sampsize, "_", mc, "_", norm, ".txt"),
                row.names = FALSE, col.names = TRUE, sep = "\t")
  }
  message("Done!")
}
