library(limma)
library(edgeR)
library(dearseq)
library(matrixStats)

### taskid
#slar_taskid <- as.numeric(Sys.getenv("SLURM_ARRAY_TASK_ID")) #1:750
for(slar_taskid in 1:750){

  load("../Data/seeds_dearseq_GBresponse.RData")
  cat("slar_taskid: ", slar_taskid, "\n")
  cat("seed used: ", seeds[slar_taskid], "\n\n")
  set.seed(seeds[slar_taskid])
  mc <- (slar_taskid -1 )%%750 %/% length(3:17) + 1
  subsample_index <- readRDS("../Data/subsample_index.rds")
  s <- (slar_taskid -1) %% (length(3:17)) + 3

  count_raw <- read.table("../Data/HeartAtrialAppendage.HeartLeftVentricle.gene_readCount.tsv",
                          sep = '\t', header = TRUE, row.names = 1)
  rownames(count_raw) <- as.character(1:nrow(count_raw))
  conditions <- read.table("../Data/HeartAtrialAppendage.HeartLeftVentricle.conditions.tsv", sep = '\t')
  condition_fact <- as.factor(as.matrix(conditions)[1, ])

  dis0 <- readRDS("../Data/HeartAtrialAppendage.HeartLeftVentricle_dis.rds")
  trueDE <- as.character(intersect(intersect(intersect(intersect(dis0[[1]], dis0[[2]]), dis0[[3]]), dis0[[4]]), dis0[[5]]))


  for(norm in c("nonorm", "permprenorm", "permpostnorm")){

    readCount <- count_raw
    condition <- condition_fact

    if(s ==17){
      sampsize <- "full"
    }else{
      sampsize <- length(subsample_index[[s]][[mc]][[1]])
    }

    message("computing sample size of ", sampsize, " with ", norm, " for simulation #", mc, "...")

    if(norm =="permprenorm"){
      # Permutation under H0
      trueDE_samplehalf <- sample(trueDE, length(trueDE)/2)
      readCount[!(rownames(readCount) %in% trueDE_samplehalf), ] <-
        t(apply(readCount[!(rownames(readCount) %in% trueDE_samplehalf), ], 1, sample))
    }

    if(norm !="nonorm"){
      # Normalization
      y <- DGEList(counts=readCount, group=condition)
      keep <- filterByExpr(y)
      y <- y[keep, keep.lib.sizes=FALSE]
      y <- calcNormFactors(y,method="TMM")
      count_norm <- cpm(y, log=TRUE)
    }else{
      count_norm <- as.matrix(readCount)
    }

    if(norm == "permpostnorm" | norm == "nonorm"){
      # Permutation under H0
      trueDE_samplehalf <- sample(trueDE, length(trueDE)/2)
      count_norm[!(rownames(count_norm) %in% trueDE_samplehalf), ] <-
        t(apply(count_norm[!(rownames(count_norm) %in% trueDE_samplehalf), ], 1, sample))
    }

    if(s != 17){
      subsamples <- unlist(subsample_index[[s]][[mc]])

      count_norm <- count_norm[, subsamples]
      condition <- condition[subsamples]
    }


    # Remove zero variance genes
    count_norm <- count_norm[matrixStats::rowVars(count_norm)>0, ]

    # Estimation
    conditions_mat <- model.matrix(~ 1 + condition)[, 2, drop=FALSE]
    dearseq_asymp_res_pvals <- dearseq::dear_seq(exprmat=count_norm,
                                                 variables2test=conditions_mat,
                                                 which_test="asymptotic",
                                                 parallel_comp=FALSE,
                                                 preprocessed=TRUE,
                                                 which_weights = "loclin")$pvals

    dearseq_asymp_res_pvals$GeneIndex <- rownames(dearseq_asymp_res_pvals)
    dearseq_asymp_res_pvals$TrueDE <- dearseq_asymp_res_pvals$GeneIndex %in% trueDE_samplehalf

    write.table(dearseq_asymp_res_pvals,
                file=paste0("dearseqAsymp_3norms/dearseq_asymp_res_pvals_", sampsize, "_", mc, "_", norm, ".txt"),
                row.names = FALSE, col.names = TRUE, sep = "\t")
  }
  message("Done!")
}
