dearseqAsymp_3norms_FDRPower <- readRDS("Results/dearseqAsymp_3norms_FDRPower.rds")
dearseqPerm_3norms_FDRPower <- readRDS("Results/dearseqPerm_3norms_FDRPower_nophiweights.rds")
Wilcoxon_3norms_FDRPower <- readRDS("Results/Wilcoxon_3norms_FDRPower.rds")
edgeR_3norms_FDRPower <- readRDS("Results/edgeR_3norms_FDRPower.rds")
DESeq2_3norms_FDRPower <- readRDS("Results/DESeq2_3norms_FDRPower.rds")
voomlimma_3norms_FDRPower <- readRDS("Results/voomlimma_3norms_FDRPower.rds")
NOISeq_3norms_FDRPower <- readRDS("Results/NOISeq_3norms_FDRPower.rds")

All_3norms_FDRPower <- rbind.data.frame(dearseqAsymp_3norms_FDRPower,
                                        dearseqPerm_3norms_FDRPower,
                                        Wilcoxon_3norms_FDRPower,
                                        edgeR_3norms_FDRPower,
                                        DESeq2_3norms_FDRPower,
                                        voomlimma_3norms_FDRPower,
                                        NOISeq_3norms_FDRPower)
All_3norms_FDRPower$Normalization <- factor(All_3norms_FDRPower$Normalization,
                                            levels=c("permprenorm", "nonorm", "permpostnorm"),
                                            ordered = TRUE)
levels(All_3norms_FDRPower$Normalization) <-  c("Permutations first", "No normalization", "Normalization first")
levels(All_3norms_FDRPower$SampleSize)[17] <- "372/386 (total)"
All_3norms_FDRPower$Method <- as.factor(All_3norms_FDRPower$Method)
levels(All_3norms_FDRPower$Method)[8] <- "limma-voom"


library(ggplot2)
library(dplyr)
library(patchwork)

# FDR ----

### Fig 1 ----

ribbon_data <- data.frame("X"=seq(0,10, by=0.001))
FDR_all <- ggplot(All_3norms_FDRPower %>% filter(!SampleSize %in% c("2", "3"),
                                                 Method %in% c("dearseq asymp", "dearseq perm", "Wilcoxon"))) +
  theme_bw() +
  annotation_logticks(size=0.2) +
  #geom_abline(color="grey65", slope=1, intercept = 0, linetype=2) +
  geom_vline(color="grey60", aes(xintercept = 0.05, linewidth="5% nominal FDR"), linetype=3) +
  geom_ribbon(data=ribbon_data,
              aes(x=X, ymin=X), ymax=1, fill="black", alpha=0.25)+
  geom_line(aes(x=NominalRate, y=FDR, color=as.factor(SampleSize), group=SampleSize)) +
  geom_point(aes(x=NominalRate, y=FDR, color=as.factor(SampleSize))) +
  scale_x_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  scale_y_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  xlab("Nominal ('claimed') FDR") +
  ylab("Empirical ('actual') FDR") +
  scale_color_manual("Sample size (per group)", values=MetBrewer::met.brewer("Hiroshige", n=17, direction = 1)) +
  scale_linewidth_manual("", values=0.5) +
  facet_grid(Normalization~Method) +
  theme(axis.ticks = element_line(linewidth=0.2),
        axis.text.x = element_text(angle=45, hjust = 1, size=6),
        axis.text.y = element_text(size=6))

ss_labs <- c("Sample size: 372/386 (total)")
names(ss_labs) <- c("372/386 (total)")
FDR_full_originalcorrected <- ggplot(All_3norms_FDRPower %>% filter(SampleSize == "372/386 (total)",
                                                                    Normalization == "Permutations first")) +# %>% filter(SampleSize == 8)) +
  theme_bw() +
  annotation_logticks(size=0.2) +
  #geom_abline(color="grey65", slope=1, intercept = 0, linetype=2) +
  geom_vline(color="grey60", aes(xintercept = 0.05, linewidth="5% nominal FDR"), linetype=3) +
  geom_ribbon(data=ribbon_data,
              aes(x=X, ymin=X), ymax=1, fill="black", alpha=0.25)+
  geom_line(aes(x=NominalRate, y=FDR, color=Method, group=Method)) +
  geom_point(aes(x=NominalRate, y=FDR, color=Method, shape=Method)) +
  scale_x_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  scale_y_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  xlab("Nominal ('claimed') FDR") +
  ylab("Empirical ('actual') FDR") +
  facet_grid(.~SampleSize, labeller = labeller(SampleSize=ss_labs))+
  scale_color_manual("Method", values=MetBrewer::met.brewer("Archambault", n=7, direction = -1)) +
  scale_shape_manual(values=c(0:2, 8, 15:17)) +
  scale_linewidth_manual("", values=0.5) +
  theme(axis.ticks = element_line(linewidth=0.2)) +
  NULL
design <- "
  AAAAA#
  AAAAA#
  AAAAA#
  BBBBBB
  BBBBBB
  BBBBBB
  BBBBBB
  BBBBBB
"
(FDR_full_originalcorrected + theme(axis.text = element_text(size=6.2)) + guides(linetype=guide_legend(order = 2), shape=guide_legend(order=1), col=guide_legend(order = 1))) /
  FDR_all + guides(size="none", col=guide_legend(ncol=2)) + theme(axis.text = element_text(size=3.4)) +
  plot_annotation(tag_levels = 'A') + plot_layout(design=design, guides = 'keep')
ggsave("Figure1-FDR-GBcorrespondance.pdf", width=9, height=10)



### Fig S1 ----

ggplot(All_3norms_FDRPower %>% filter(!SampleSize %in% c("2", "3"))) +
  theme_bw() +
  annotation_logticks(size=0.2) +
  #geom_abline(color="grey65", slope=1, intercept = 0, linetype=2) +
  geom_vline(color="grey60", aes(xintercept = 0.05, size="5% nominal FDR"), linetype=3) +
  geom_ribbon(data=ribbon_data,
              aes(x=X, ymin=X), ymax=1, fill="black", alpha=0.25)+
  geom_line(aes(x=NominalRate, y=FDR, color=as.factor(SampleSize), group=SampleSize), size=0.4) +
  geom_point(aes(x=NominalRate, y=FDR, color=as.factor(SampleSize)), size=1.1) +
  scale_x_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  scale_y_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  xlab("Nominal ('claimed') FDR") +
  ylab("Empirical ('actual') FDR") +
  scale_color_manual("Sample size (per group)", values=MetBrewer::met.brewer("Hiroshige", n=17, direction = 1)) +
  scale_size_manual("", values=0.5) +
  facet_grid(Normalization~Method) +
  guides(col=guide_legend(ncol=2)) +
  #theme(axis.text = element_text(size=3)) +
  theme(axis.ticks = element_line(size=0.2)) +
  theme(axis.ticks = element_line(linewidth=0.2),
        axis.text.x = element_text(angle=45, hjust = 1, size=6),
        axis.text.y = element_text(size=6)) +
  NULL
ggsave("FigureS1-FDR-GBcorrespondance.pdf", width=12, height=5)

# Power ----

### power1 ----

levels(All_3norms_FDRPower$SampleSize)[17] <- "372/386\n(total)"

nr_labs <- c("Nominal Rate: 1%", "Nominal Rate: 10%")
names(nr_labs) <- c("0.01", "0.1")
power1 <- ggplot(All_3norms_FDRPower %>% filter(Method %in% c("dearseq asymp", "dearseq perm", #"voomlimma", "NOISeq",
                                                              "Wilcoxon"),
                                                Normalization != "Permutations first",
                                                !SampleSize %in% c("2", "3"),
                                                NominalRate %in% c(0.01, 0.1))) +
  theme_bw() +
  geom_vline(aes(size="Asymptotic convergence\nreached for dearseq asymp", xintercept = "40"), color="grey25", linetype=2) +
  geom_line(aes(x=SampleSize, y=Power, color=Method, group=Method)) +
  geom_point(aes(x=SampleSize, y=Power, color=Method, shape=Method)) +
  xlab("Sample size (per group)") +
  ylab("Empirical Power") +
  scale_size_manual("Sample size = 40", values=0.5)+
  scale_color_manual("Method", values=MetBrewer::met.brewer("Archambault", n=7, direction = -1)[c(1:2, 7)]) +
  scale_shape_manual(values=c(0:1, 17)) +
  facet_grid(Normalization~NominalRate,
             labeller = labeller(NominalRate=nr_labs)) +
  guides(size=guide_legend(order=1)) +
  theme(axis.ticks = element_line(size=0.3)) +
  NULL


### power2 ----
ss_labs <- c("Sample size: 372/386 (total)")
names(ss_labs) <- c("372/386\n(total)")
power2 <- ggplot(All_3norms_FDRPower %>% filter(Method %in% c("dearseq asymp", "dearseq perm", "Wilcoxon"#, "voomlimma", "NOISeq"
),
Normalization != "Permutations first",
SampleSize == "372/386\n(total)")) +
  theme_bw() +
  annotation_logticks(sides = "b", size=0.3) +
  geom_line(aes(x=NominalRate, y=Power, color=Method, group=Method)) +
  geom_point(aes(x=NominalRate, y=Power, color=Method, shape=Method)) +
  scale_x_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  xlab("Nominal ('claimed') FDR") +
  ylab("Empirical Power") +
  scale_color_manual("Method", values=MetBrewer::met.brewer("Archambault", n=7, direction = -1)[c(1:2, 7)]) +
  scale_shape_manual(values=c(0:1, 17)) +
  facet_grid(Normalization~SampleSize, labeller = labeller(SampleSize=ss_labs)) +
  theme(axis.ticks = element_line(size=0.3)) +
  NULL

### Fig 2 ----
design <- "
  AAA
  BBC
"

power1 + power2 + guide_area() +
  plot_annotation(tag_levels = 'A') + plot_layout(design=design, guides = 'collect') &
  theme(legend.box = "vertical", legend.box.just = "left", axis.text=element_text(size=4.5))
ggsave("Figure2-Power-GBcorrespondance.pdf", width=7, height=8)

### Fig S2 power ----

power1_all <- ggplot(All_3norms_FDRPower %>% filter(
  Normalization != "Permutations first",
  !SampleSize %in% c("2", "3"),
  NominalRate %in% c(0.01, 0.1))) +
  theme_bw() +
  geom_vline(aes(size="Asymptotic convergence\nreached for dearseq asymp", xintercept = "40"), color="grey25", linetype=2) +
  geom_line(aes(x=SampleSize, y=Power, color=Method, group=Method)) +
  geom_point(aes(x=SampleSize, y=Power, color=Method, shape=Method)) +
  xlab("Sample size (per group)") +
  ylab("Empirical Power") +
  scale_size_manual("Sample size = 40", values=0.5)+
  scale_color_manual("Method", values=MetBrewer::met.brewer("Archambault", n=7, direction = -1)) +
  scale_shape_manual(values=c(0:2, 8, 15:17)) +
  facet_grid(Normalization~NominalRate,
             labeller = labeller(NominalRate=nr_labs)) +
  NULL


power2_all <- ggplot(All_3norms_FDRPower %>% filter(Normalization != "Permutations first",
                                                    SampleSize == "372/386\n(total)")) +
  theme_bw() +
  annotation_logticks(sides = "b", size=0.3) +
  geom_line(aes(x=NominalRate, y=Power, color=Method, group=Method)) +
  geom_point(aes(x=NominalRate, y=Power, color=Method, shape=Method)) +
  scale_x_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  xlab("Nominal ('claimed') FDR") +
  ylab("Empirical Power") +
  scale_color_manual("Method", values=MetBrewer::met.brewer("Archambault", n=7, direction = -1)) +
  scale_shape_manual(values=c(0:2, 8, 15:17)) +
  facet_grid(Normalization~SampleSize, labeller = labeller(SampleSize=ss_labs)) +
  theme(axis.ticks = element_line(size=0.3)) +
  NULL

design <- "
  AAA
  BBC
"

power1_all + power2_all + guide_area() +
  plot_annotation(tag_levels = 'A') + plot_layout(design=design, guides = 'collect') &
  theme(legend.box = "vertical", legend.box.just = "left", axis.text=element_text(size=4.5))
ggsave("FigureS2-Power-GBcorrespondance.pdf", width=7, height=8)


### Fig S3 power ----

ggplot(All_3norms_FDRPower %>% filter(
  SampleSize == "372/386\n(total)")) +
  theme_bw() +
  annotation_logticks(sides = "b", size=0.3) +
  geom_line(aes(x=FDR, y=Power, color=Method, group=Method)) +
  geom_point(aes(x=FDR, y=Power, color=Method, shape=Method)) +
  scale_x_log10(breaks=c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1),
                minor_breaks= rep(1:9, 21)*(10^rep(-10:10, each=9)),
                labels = paste0(round(c(0.00001, 0.0001, 0.001, 0.01, 0.05, 0.1, 0.2, 1)*100, digits=3), "%"),
                limits=c(0.00001, 1), expand = c(0.05,0,0,0)) +
  xlab("Empirical ('actual') FDR") +
  ylab("Empirical Power") +
  scale_color_manual("Method", values=MetBrewer::met.brewer("Archambault", n=7, direction = -1)) +
  scale_shape_manual(values=c(0:2, 8, 15:17)) +
  facet_grid(Normalization~SampleSize, labeller = labeller(SampleSize=ss_labs)) +
  theme(axis.ticks = element_line(size=0.3), axis.text = element_text(size = 6)) +
  NULL
ggsave("FigureS3-PoweractualFDR-GBcorrespondance.pdf", width=6, height=6)


# Lib size ----

 ### Fig S4 ----

count_raw <- read.table("Data/HeartAtrialAppendage.HeartLeftVentricle.gene_readCount.tsv",
                        sep = '\t', header = TRUE, row.names = 1)
lib_size <- colSums(count_raw)
conditions <- read.table("Data/HeartAtrialAppendage.HeartLeftVentricle.conditions.tsv", sep = '\t')
condition_fact <- as.factor(as.matrix(conditions)[1, ])

library(ggplot2)
library(MetBrewer)
lib_size2plot <- cbind.data.frame("LibrarySize" = lib_size,
                                  "Tissue" = condition_fact,
                                  "Sample" = factor(colnames(count_raw), levels=colnames(count_raw), ordered = TRUE))
levels(lib_size2plot$Tissue) <- c("Atrial Appendage", "Left ventricle")

p_bar <- ggplot(lib_size2plot, aes(fill= Tissue)) +
  theme_bw() +
  geom_col(aes(x=Sample, y=LibrarySize)) +
  ylab("Library size") +
  scale_fill_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  theme(axis.text.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.ticks.x = element_blank()) +
  NULL

tt <- t.test(LibrarySize ~ Tissue, data = lib_size2plot)
wt <- wilcox.test(LibrarySize ~ Tissue, data = lib_size2plot)

p_density <- ggplot(lib_size2plot, aes(fill= Tissue)) +
  theme_bw() +
  geom_density(aes(x=LibrarySize), color="white", alpha=0.5, ) +
  xlab("Library size") +
  scale_fill_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  NULL

p_boxplot <- ggplot(lib_size2plot) +
  theme_bw() +
  geom_boxplot(aes(x=Tissue, y=LibrarySize, color=Tissue, fill= Tissue), alpha=0.5, ) +
  ylab("Library size") +
  scale_fill_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  scale_color_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  guides(fill = "none", color="none") +
  theme(panel.grid.major.x = element_blank()) +
  geom_label(label = paste0("t-test p-value=", round(tt$p.value, digits = 3)),
             x=1.5, y=1.6e+08, size=1.8) +
  NULL

p_violin <- ggplot(lib_size2plot) +
  theme_bw() +
  geom_violin(aes(x=Tissue, y=LibrarySize, color=Tissue, fill= Tissue), alpha=0.5) +
  ylab("Library size") +
  scale_fill_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  scale_color_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  guides(fill = "none", color="none") +
  theme(panel.grid.major.x = element_blank()) +
  geom_label(label = paste0("Wilcoxon test p-value=", round(wt$p.value, digits = 3)),
             x=1.5, y=1.6e+08, size=1.8) +
  NULL

library(patchwork)
patch <- p_bar / (p_boxplot + p_violin) + plot_annotation(tag_levels = "A")
#ggsave(plot = patch, "FigureS4-LibrarySize-GBcorrespondence.png", height=5.5, width=8.2, dpi = 600)
ggsave(plot = patch, "FigureS4-LibrarySize-GBcorrespondence.pdf", height=5.5, width=8.2)

### Fig S5 true DE ----
dis0 <- readRDS("Data/HeartAtrialAppendage.HeartLeftVentricle_dis.rds")
trueDE <- intersect(intersect(intersect(intersect(dis0[[1]], dis0[[2]]), dis0[[3]]), dis0[[4]]), dis0[[5]])
LS_trueDE <- colSums(count_raw[trueDE, ])

LS_trueDE2plot <- cbind.data.frame("LibrarySize" = LS_trueDE,
                                   "PropCountTrueDE" = LS_trueDE/lib_size,
                                   "Tissue" = condition_fact,
                                   "Sample" = factor(colnames(count_raw), levels=colnames(count_raw), ordered = TRUE))
levels(LS_trueDE2plot$Tissue) <- c("Atrial Appendage", "Left ventricle")

p_bar <- ggplot(LS_trueDE2plot, aes(fill= Tissue)) +
  theme_bw() +
  geom_col(aes(x=Sample, y=LibrarySize)) +
  ylab("Library size of true DE genes only") +
  scale_fill_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  theme(axis.text.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.title = element_text(size = 10)) +
  NULL

tt <- t.test(LibrarySize ~ Tissue, data = LS_trueDE2plot)
wt <- wilcox.test(LibrarySize ~ Tissue, data = LS_trueDE2plot)

p_boxplot <- ggplot(LS_trueDE2plot) +
  theme_bw() +
  geom_boxplot(aes(x=Tissue, y=LibrarySize, color=Tissue, fill= Tissue), alpha=0.5, ) +
  ylab("Library size of true DE genes only") +
  scale_fill_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  scale_color_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  guides(fill = "none", color="none") +
  theme(panel.grid.major.x = element_blank(),
        axis.title = element_text(size = 10)) +
  geom_label(label = paste0("t-test p-value=", format(tt$p.value, digits = 3)),
             x=1.5, y=1e+08, size=1.8) +
  NULL

p_violin <- ggplot(LS_trueDE2plot) +
  theme_bw() +
  geom_violin(aes(x=Tissue, y=LibrarySize, color=Tissue, fill= Tissue), alpha=0.5) +
  ylab("Library size of true DE genes only") +
  scale_fill_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  scale_color_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  guides(fill = "none", color="none") +
  theme(panel.grid.major.x = element_blank(),
        axis.title = element_text(size = 10)) +
  geom_label(label = paste0("Wilcoxon test p-value=", format(wt$p.value, digits = 3)),
             x=1.4, y=1e+08, size=1.8) +
  NULL
p_bar2 <- ggplot(LS_trueDE2plot, aes(color= Tissue)) +
  theme_bw() +
  geom_point(aes(x=Sample, y=PropCountTrueDE), size=0.5, alpha=0.6) +
  ylab(paste0("Proportion of total library size\n attributable to the ",
              length(trueDE),
              " true DE genes")) +
  ylim(0,1) +
  scale_color_manual("Heart tissue", values = MetBrewer::met.brewer("Java", n=2)) +
  guides(fill = "none", color="none") +
  theme(axis.text.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.ticks.x = element_blank(),
        axis.title = element_text(size = 10)) +
  NULL
patch <- p_bar / (p_boxplot + p_violin) / p_bar2 + plot_annotation(tag_levels = "A")
ggsave(plot = patch, "FigureS5-LibrarySizeTrueDE-GBcorrespondence.pdf", height=7.75, width=8.2)



### Fig S6 toy example----
library(dplyr)
library(xtable)

set.seed(123)
n <- 10
a <- rep(0:1, each = n/2)
p1 <- 0.4*a + (1-a)*0.1
p2 <- 0.2
p3 <- 1 - p1 - p2
lib_size <- c(80, 100, 150, 500, 800,
              1000, 5000, 5000, 10000, 15000)
g1 <- p1*lib_size + rpois(n, lambda = lib_size/100)
g2 <- p2*lib_size + rpois(n, lambda = lib_size/100)
g3 <- p3*lib_size + rpois(n, lambda = lib_size/100)

ds <- tibble(lib_size,
             a,
             g1,
             g2,
             g3)
ds
wilcox.test(ds$g2[ds$a == 0], ds$g2[ds$a == 1])

norm_ds <- ds %>%
  mutate_at(vars(g1:g3), ~log(./lib_size,
                              base = 2))
wilcox.test(norm_ds$g2[norm_ds$a == 0], norm_ds$g2[norm_ds$a == 1])
norm_ds


perm_ds <- ds %>%
  mutate(g2 = sample(g2)) %>%
  mutate_at(vars(lib_size), ~g1+g2+g3)
wilcox.test(perm_ds$g2[perm_ds$a == 0], perm_ds$g2[perm_ds$a == 1])
perm_ds

norm_perm_ds <- perm_ds %>%
  mutate_at(vars(g1:g3), ~log(./lib_size,
                              base = 2))
wilcox.test(norm_perm_ds$g2[norm_perm_ds$a == 0], norm_perm_ds$g2[norm_perm_ds$a == 1])
norm_perm_ds

colnames(ds) <- c("Library size", "A", "Gene 1", "Gene 2", "Gene 3")
colnames(norm_ds) <- c("Library size", "A", "Gene 1", "Gene 2", "Gene 3")
colnames(perm_ds) <- c("Library size", "A", "Gene 1", "Gene 2", "Gene 3")
colnames(norm_perm_ds) <- c("Library size", "A", "Gene 1", "Gene 2", "Gene 3")

print(xtable(ds, align = rep("r", 6), digits = 0), include.rownames=FALSE)
print(xtable(norm_ds, align = rep("r", 6), digits = c(0,0,2,2,2,2)), include.rownames=FALSE)
print(xtable(perm_ds, align = rep("r", 6), digits = 0), include.rownames=FALSE)
print(xtable(norm_perm_ds, align = rep("r", 6), digits = c(0,0,2,2,2,2)), include.rownames=FALSE)


nsim <- 500
pval <- numeric(nsim)
norm_pval <- numeric(nsim)
perm_pval <- numeric(nsim)
norm_perm_pval <- numeric(nsim)
for(i in 1:500){
  g1 <- p1*lib_size + rpois(n, lambda = lib_size/100)
  g2 <- p2*lib_size + rpois(n, lambda = lib_size/100)
  g3 <- p3*lib_size + rpois(n, lambda = lib_size/100)

  ds <- tibble(lib_size,
               a,
               g1,
               g2,
               g3)
  pval[i] <- wilcox.test(ds$g2[ds$a == 0], ds$g2[ds$a == 1])$p.value

  norm_ds <- ds %>%
    mutate_at(vars(g1:g3), ~log(./lib_size,
                                base = 2))
  norm_pval[i] <- wilcox.test(norm_ds$g2[norm_ds$a == 0], norm_ds$g2[norm_ds$a == 1])$p.value

  perm_ds <- ds %>%
    mutate(g2 = sample(g2)) %>%
    mutate_at(vars(lib_size), ~g1+g2+g3)
  perm_pval[i] <- wilcox.test(perm_ds$g2[perm_ds$a == 0], perm_ds$g2[perm_ds$a == 1])$p.value

  norm_perm_ds <- perm_ds %>%
    mutate_at(vars(g1:g3), ~log(./lib_size,
                                base = 2))
  norm_perm_pval[i] <- wilcox.test(norm_perm_ds$g2[norm_perm_ds$a == 0], norm_perm_ds$g2[norm_perm_ds$a == 1])$p.value
}
bp2plot <- reshape2::melt(cbind.data.frame("original data" = pval, "normalized data" = norm_pval,
                                           "permuted data" = perm_pval, "normalized permuted data"=norm_perm_pval),
                          value.name="WilcoxonPval", variable.name="DataType")

ggplot(bp2plot, aes(y=WilcoxonPval, x = DataType)) +
  geom_boxplot(aes(color=DataType, fill=DataType), alpha=0.5) +
  ylab("Wilcoxon test p-value") +
  xlab("") +
  theme_bw() +
  theme(panel.grid.major.x = element_blank(),
        axis.text.x = element_text(angle=45, hjust=1)) +
  guides(color="none", fill="none") +
  scale_color_manual(values=MetBrewer::met.brewer("Egypt", n=4, direction = -1)) +
  scale_fill_manual(values=MetBrewer::met.brewer("Egypt", n=4, direction = -1)) +
  NULL
ggsave("FigureS6-ToyExample-GBcorrespondence.pdf", height=4, width=4)
